/**
 * @private !!!! Decide how to expose this
 */
export declare const openapiJson: {
    openapi: string;
    info: {
        title: string;
        version: string;
        description: string;
    };
    paths: {
        '/': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'text/markdown': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/login': {
            post: {
                summary: string;
                description: string;
                requestBody: {
                    required: boolean;
                    content: {
                        'application/json': {
                            schema: {
                                type: string;
                                properties: {
                                    username: {
                                        type: string;
                                    };
                                    password: {
                                        type: string;
                                    };
                                    appId: {
                                        type: string;
                                    };
                                };
                            };
                        };
                    };
                };
                responses: {
                    '201': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        isSuccess: {
                                            type: string;
                                        };
                                        message: {
                                            type: string;
                                        };
                                        error: {
                                            type: string;
                                        };
                                        identification: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '400': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        error: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '401': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        isSuccess: {
                                            type: string;
                                            enum: boolean[];
                                        };
                                        message: {
                                            type: string;
                                        };
                                        error: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                };
            };
        };
        '/books': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    items: {
                                        type: string;
                                    };
                                };
                            };
                        };
                    };
                    '500': {
                        description: string;
                        content: {
                            'text/plain': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/books/{bookId}': {
            get: {
                summary: string;
                description: string;
                parameters: {
                    in: string;
                    name: string;
                    required: boolean;
                    schema: {
                        type: string;
                    };
                    description: string;
                }[];
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'text/markdown': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                    '404': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        error: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '500': {
                        description: string;
                        content: {
                            'text/plain': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/executions': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    items: {
                                        type: string;
                                        properties: {
                                            nonce: {
                                                type: string;
                                            };
                                            taskId: {
                                                type: string;
                                            };
                                            taskType: {
                                                type: string;
                                            };
                                            status: {
                                                type: string;
                                            };
                                            createdAt: {
                                                type: string;
                                                format: string;
                                            };
                                            updatedAt: {
                                                type: string;
                                                format: string;
                                            };
                                        };
                                    };
                                };
                            };
                        };
                    };
                };
            };
        };
        '/executions/last': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        nonce: {
                                            type: string;
                                        };
                                        taskId: {
                                            type: string;
                                        };
                                        taskType: {
                                            type: string;
                                        };
                                        status: {
                                            type: string;
                                        };
                                        errors: {
                                            type: string;
                                            items: {
                                                type: string;
                                            };
                                        };
                                        warnings: {
                                            type: string;
                                            items: {
                                                type: string;
                                            };
                                        };
                                        createdAt: {
                                            type: string;
                                            format: string;
                                        };
                                        updatedAt: {
                                            type: string;
                                            format: string;
                                        };
                                        currentValue: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '404': {
                        description: string;
                        content: {
                            'text/plain': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/executions/{taskId}': {
            get: {
                summary: string;
                description: string;
                parameters: {
                    in: string;
                    name: string;
                    required: boolean;
                    schema: {
                        type: string;
                    };
                    description: string;
                }[];
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        nonce: {
                                            type: string;
                                        };
                                        taskId: {
                                            type: string;
                                        };
                                        taskType: {
                                            type: string;
                                        };
                                        status: {
                                            type: string;
                                        };
                                        errors: {
                                            type: string;
                                            items: {
                                                type: string;
                                            };
                                        };
                                        warnings: {
                                            type: string;
                                            items: {
                                                type: string;
                                            };
                                        };
                                        createdAt: {
                                            type: string;
                                            format: string;
                                        };
                                        updatedAt: {
                                            type: string;
                                            format: string;
                                        };
                                        currentValue: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '404': {
                        description: string;
                        content: {
                            'text/plain': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/executions/new': {
            post: {
                summary: string;
                description: string;
                requestBody: {
                    required: boolean;
                    content: {
                        'application/json': {
                            schema: {
                                type: string;
                                properties: {
                                    pipelineUrl: {
                                        type: string;
                                        description: string;
                                    };
                                    book: {
                                        type: string;
                                        description: string;
                                    };
                                    inputParameters: {
                                        type: string;
                                        description: string;
                                    };
                                    identification: {
                                        type: string;
                                        description: string;
                                    };
                                };
                            };
                        };
                    };
                };
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                    '400': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                    properties: {
                                        error: {
                                            type: string;
                                        };
                                    };
                                };
                            };
                        };
                    };
                    '404': {
                        description: string;
                        content: {
                            'text/plain': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
        '/api-docs': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                    };
                };
            };
        };
        '/swagger': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                    };
                };
            };
        };
        '/openapi': {
            get: {
                summary: string;
                description: string;
                responses: {
                    '200': {
                        description: string;
                        content: {
                            'application/json': {
                                schema: {
                                    type: string;
                                };
                            };
                        };
                    };
                };
            };
        };
    };
    components: {
        schemas: {
            Error: {
                type: string;
                properties: {
                    error: {
                        type: string;
                    };
                };
            };
            ExecutionTaskSummary: {
                type: string;
                properties: {
                    nonce: {
                        type: string;
                    };
                    taskId: {
                        type: string;
                    };
                    taskType: {
                        type: string;
                    };
                    status: {
                        type: string;
                    };
                    createdAt: {
                        type: string;
                        format: string;
                    };
                    updatedAt: {
                        type: string;
                        format: string;
                    };
                };
            };
            ExecutionTaskFull: {
                type: string;
                properties: {
                    nonce: {
                        type: string;
                    };
                    taskId: {
                        type: string;
                    };
                    taskType: {
                        type: string;
                    };
                    status: {
                        type: string;
                    };
                    errors: {
                        type: string;
                        items: {
                            type: string;
                        };
                    };
                    warnings: {
                        type: string;
                        items: {
                            type: string;
                        };
                    };
                    createdAt: {
                        type: string;
                        format: string;
                    };
                    updatedAt: {
                        type: string;
                        format: string;
                    };
                    currentValue: {
                        type: string;
                    };
                };
            };
        };
    };
    tags: {
        name: string;
        description: string;
    }[];
};
/**
 * Note: [💞] Ignore a discrepancy between file name and entity name
 */
